@@ -30,9 +30,22 @@ impl From<ChaChaDecryptorError> for PyErr {
     }
 }
 
+const CHACHA_KEY: &str = "=";
+const CHACHA_KEYS: [&str; 8] = [
+    "K9Ca5igncsk",
+    "uOVtMpqHxFv",
+    "OnQrV02thA",
+    "MkdeyU95BJa",
+    "SjpNhdKK89V",
+    "rl6OrLALPQh",
+    "oXafvEwR54",
+    "4ZzYokf5I7Z",
+];
+
 #[derive(Clone, Debug)]
-#[pyclass]
+#[pyclass(frozen)]
 pub struct ChaChaDecryptor {
+    #[pyo3(get)]
     common_chacha_key_bs: Vec<u8>,
 }
 
@@ -40,26 +53,15 @@ pub struct ChaChaDecryptor {
 impl ChaChaDecryptor {
     #[new]
     pub fn new() -> PyResult<Self> {
-        let chacha_key = "=";
-        let chacha_keys = [
-            "K9Ca5igncsk",
-            "uOVtMpqHxFv",
-            "OnQrV02thA",
-            "MkdeyU95BJa",
-            "SjpNhdKK89V",
-            "rl6OrLALPQh",
-            "oXafvEwR54",
-            "4ZzYokf5I7Z",
-        ];
-
         let common_key_str = format!(
             "{}{}{}{}{}",
-            chacha_keys[0], chacha_keys[3], chacha_keys[5], chacha_keys[2], chacha_key
+            CHACHA_KEYS[0], CHACHA_KEYS[3], CHACHA_KEYS[5], CHACHA_KEYS[2], CHACHA_KEY
         );
 
         let common_key = BASE64_STANDARD
             .decode(common_key_str)
             .map_err(ChaChaDecryptorError::Base64Error)?;
+
         let common_chacha_key_bs =
             Self::key_decrypt_impl(&common_key, "Build/Json/GameplayConfig/");
 
@@ -88,8 +90,8 @@ impl ChaChaDecryptor {
         result
     }
 
+    #[staticmethod]
     pub fn key_decrypt<'py>(
-        &self,
         py: pyo3::Python<'py>,
         data: &Bound<'py, PyAny>,
         key: &str,
